@@ -28,105 +28,105 @@
 #' 'Xb.Min', the mean allele ratio 'Xb.Mean', its standard deviation 'Xb.Stdv',
 #' the XXth percentile 'Xb.Perc.XX'
 #' For more details see \code{min}, \code{mean}, \code{sd}, \code{quantile}.
-#' 
+#'
 #' @param data data frame from a balance analysis by \code{calculateHb}
 #'  and \code{calculateLb}.
 #' @param scope string, summarize 'global' or 'locus'.
 #' @param quant numeric, quantile to calculate.
-#' 
+#'
 #' @return data.frame with summarized result.
-#' 
+#'
 #' @export
-#' 
+#'
 #' @importFrom stats sd quantile setNames
 #' @importFrom data.table data.table
-#' 
+#'
 
 
-tableBalance <- function(data, scope="locus", quant=0.05){
-  
+tableBalance <- function(data, scope = "locus", quant = 0.05) {
   message("Function to calculate summary statistics for balance data.")
-  
+
   # Prepare -------------------------------------------------------------------
-  
-  if("Hb" %in% names(data)){
-    
+
+  if ("Hb" %in% names(data)) {
     message("Hb column detected.")
-    
+
     targetCol <- quote(Hb)
-    
-  } else if("Lb" %in% names(data)){
-    
+  } else if ("Lb" %in% names(data)) {
     message("Lb column detected.")
-    
+
     targetCol <- quote(Lb)
-    
   }
-  
+
   # Create column names.
-  nameN <- paste(targetCol,"n", sep=".")
-  nameMin <- paste(targetCol,"Min", sep=".")
-  nameMean <- paste(targetCol,"Mean", sep=".")
-  nameSd <- paste(targetCol,"Sd", sep=".")
-  nameMax <- paste(targetCol,"Max", sep=".")
-  namePerc <- paste(targetCol,"Perc", quant*100, sep=".")
-  
+  nameN <- paste(targetCol, "n", sep = ".")
+  nameMin <- paste(targetCol, "Min", sep = ".")
+  nameMean <- paste(targetCol, "Mean", sep = ".")
+  nameSd <- paste(targetCol, "Sd", sep = ".")
+  nameMax <- paste(targetCol, "Max", sep = ".")
+  namePerc <- paste(targetCol, "Perc", quant * 100, sep = ".")
+
   # Convert to data.table.
   DT <- data.table::data.table(data)
-  
+
   # Check for and remove NA in target column.
-  if(any(is.na(DT[, eval(targetCol)]))){
-    
+  if (any(is.na(DT[, eval(targetCol)]))) {
     tmp1 <- nrow(DT)
-    #DT <- DT[!is.na(get(targetCol))]
+    # DT <- DT[!is.na(get(targetCol))]
     DT <- DT[!is.na(eval(targetCol))]
     tmp2 <- nrow(DT)
-    
+
     message("Removed ", tmp1 - tmp2, " rows with NA.")
-    
   }
-  
+
   # Calculate -----------------------------------------------------------------
-  
-  if(scope == "global") {
-    
+
+  if (scope == "global") {
     message("Calculating global summary statistics across all data...")
-    
-    DT <- DT[, j = setNames(list(.N,
-                                 min(eval(targetCol)),
-                                 mean(eval(targetCol)),
-                                 sd(eval(targetCol)),
-                                 max(eval(targetCol)),
-                                 quantile(eval(targetCol), quant)),
-                            list(nameN, nameMin, nameMean, nameSd,
-                                 nameMax, namePerc))]
-    
-  } else if(scope == "locus") {
-    
+
+    DT <- DT[, j = setNames(
+      list(
+        .N,
+        min(eval(targetCol)),
+        mean(eval(targetCol)),
+        sd(eval(targetCol)),
+        max(eval(targetCol)),
+        quantile(eval(targetCol), quant)
+      ),
+      list(
+        nameN, nameMin, nameMean, nameSd,
+        nameMax, namePerc
+      )
+    )]
+  } else if (scope == "locus") {
     message("Calculating summary statistics by locus...")
-      
-    DT <- DT[, j = setNames(list(.N,
-                                 min(eval(targetCol)),
-                                 mean(eval(targetCol)),
-                                 sd(eval(targetCol)),
-                                 max(eval(targetCol)),
-                                 quantile(eval(targetCol), quant)),
-                            list(nameN, nameMin, nameMean, nameSd,
-                                 nameMax, namePerc)),
-             by=list(Marker)]
-    
+
+    DT <- DT[,
+      j = setNames(
+        list(
+          .N,
+          min(eval(targetCol)),
+          mean(eval(targetCol)),
+          sd(eval(targetCol)),
+          max(eval(targetCol)),
+          quantile(eval(targetCol), quant)
+        ),
+        list(
+          nameN, nameMin, nameMean, nameSd,
+          nameMax, namePerc
+        )
+      ),
+      by = list(Marker)
+    ]
   } else {
-    
     message("Required column not in dataset. Return data unchanged.")
-    
   }
-  
+
   # Convert to data.frame.
   res <- as.data.frame(DT)
-  
+
   # Update audit trail.
   res <- auditTrail(obj = res, f.call = match.call(), package = "strvalidator")
-  
+
   return(res)
-  
-}
\ No newline at end of file
+}
